==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface StressChaosSpecFluent<A extends StressChaosSpecFluent<A>> extends Fluent<A>{
  public A addToContainerNames(Integer index,String item);
  public A setToContainerNames(Integer index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(Integer index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public StressChaosSpecFluent.SelectorNested<A> withNewSelector();
  public StressChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public StressChaosSpecFluent.SelectorNested<A> editSelector();
  public StressChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public StressChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getStressngStressors();
  public A withStressngStressors(String stressngStressors);
  public Boolean hasStressngStressors();
  
  /**
   * This method has been deprecated, please use method buildStressors instead.
   * @return The buildable object.
   */
  @Deprecated
  public Stressors getStressors();
  public Stressors buildStressors();
  public A withStressors(Stressors stressors);
  public Boolean hasStressors();
  public StressChaosSpecFluent.StressorsNested<A> withNewStressors();
  public StressChaosSpecFluent.StressorsNested<A> withNewStressorsLike(Stressors item);
  public StressChaosSpecFluent.StressorsNested<A> editStressors();
  public StressChaosSpecFluent.StressorsNested<A> editOrNewStressors();
  public StressChaosSpecFluent.StressorsNested<A> editOrNewStressorsLike(Stressors item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<StressChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  public interface StressorsNested<N> extends Nested<N>,StressorsFluent<StressChaosSpecFluent.StressorsNested<N>>{
    public N and();
    public N endStressors();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface StressChaosSpecFluent<A extends StressChaosSpecFluent<A>> extends Fluent<A>{
  public A addToContainerNames(int index,String item);
  public A setToContainerNames(int index,String item);
  public A addToContainerNames(java.lang.String... items);
  public A addAllToContainerNames(Collection<String> items);
  public A removeFromContainerNames(java.lang.String... items);
  public A removeAllFromContainerNames(Collection<String> items);
  public List<String> getContainerNames();
  public String getContainerName(int index);
  public String getFirstContainerName();
  public String getLastContainerName();
  public String getMatchingContainerName(Predicate<String> predicate);
  public Boolean hasMatchingContainerName(Predicate<String> predicate);
  public A withContainerNames(List<String> containerNames);
  public A withContainerNames(java.lang.String... containerNames);
  public Boolean hasContainerNames();
  public String getDuration();
  public A withDuration(String duration);
  public Boolean hasDuration();
  public String getMode();
  public A withMode(String mode);
  public Boolean hasMode();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSelectorSpec getSelector();
  public PodSelectorSpec buildSelector();
  public A withSelector(PodSelectorSpec selector);
  public Boolean hasSelector();
  public StressChaosSpecFluent.SelectorNested<A> withNewSelector();
  public StressChaosSpecFluent.SelectorNested<A> withNewSelectorLike(PodSelectorSpec item);
  public StressChaosSpecFluent.SelectorNested<A> editSelector();
  public StressChaosSpecFluent.SelectorNested<A> editOrNewSelector();
  public StressChaosSpecFluent.SelectorNested<A> editOrNewSelectorLike(PodSelectorSpec item);
  public String getStressngStressors();
  public A withStressngStressors(String stressngStressors);
  public Boolean hasStressngStressors();
  
  /**
   * This method has been deprecated, please use method buildStressors instead.
   * @return The buildable object.
   */
  @Deprecated
  public Stressors getStressors();
  public Stressors buildStressors();
  public A withStressors(Stressors stressors);
  public Boolean hasStressors();
  public StressChaosSpecFluent.StressorsNested<A> withNewStressors();
  public StressChaosSpecFluent.StressorsNested<A> withNewStressorsLike(Stressors item);
  public StressChaosSpecFluent.StressorsNested<A> editStressors();
  public StressChaosSpecFluent.StressorsNested<A> editOrNewStressors();
  public StressChaosSpecFluent.StressorsNested<A> editOrNewStressorsLike(Stressors item);
  public String getValue();
  public A withValue(String value);
  public Boolean hasValue();
  public interface SelectorNested<N> extends Nested<N>,PodSelectorSpecFluent<StressChaosSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  public interface StressorsNested<N> extends Nested<N>,StressorsFluent<StressChaosSpecFluent.StressorsNested<N>>{
    public N and();
    public N endStressors();
    
  }
  
}
